@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2021-2022, by Samuel Williams.
+# Copyright, 2021-2023, by Samuel Williams.
 
 require 'bake/modernize'
 
@@ -10,7 +10,7 @@ def git
 end
 
 def update(root:)
-	if current_branch != "main"
+	if current_branch == "master"
 		# https://github.com/github/renaming
 		system("git", "branch", "-M", "main")
 		system("git", "push", "-u", "origin", "main")
